package org.jeecg.modules.ctop.service.impl;

import cn.com.ctop.common.utils.HttpUtils;
import cn.com.ctop.common.utils.PropertiesUtils;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.jeecg.modules.ctop.entity.*;
import org.jeecg.modules.ctop.mapper.*;
import org.jeecg.modules.ctop.service.ITouTiaoAdvertiserService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;

@Service
public class TouTiaoAdvertiserServiceImpl implements ITouTiaoAdvertiserService {
    private static final Logger logger = LoggerFactory.getLogger(TouTiaoAdvertiserServiceImpl.class);
    @Autowired
    private CTopOauthTokenMapper cTopOauthTokenMapper;
    private CTopOauthToken getOAuthTokenByAccountId(String accountId){
        QueryWrapper<CTopOauthToken> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("advertiser_id", accountId).orderByDesc("create_time");
        CTopOauthToken cTopOauthToken = cTopOauthTokenMapper.selectOne(queryWrapper);
        return cTopOauthToken;
    }
    @Override
    public Map<String, Object> getAdvertiserInfo(String accountId) {
        Map<String,Object>resultMap = new HashMap<>();
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_advertiser_info");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());
        TreeMap<String,Object>params = new TreeMap<>();
        params.put("advertiser_ids","["+cTopOauthToken.getAccountId()+"]");
        String result = HttpUtils.httpGetRequest(url,headers,params);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("获取广告主信息接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","获取广告主信息接口异常");
            return resultMap;
        }
        JSONArray data = jsonObject.getJSONArray("data");
        if(null==data||data.size()<=0){
            resultMap.put("code",0);
            resultMap.put("message","广告主信息不存在");
            return resultMap;
        }
        for (int i=0;i<data.size();i++){
            JSONObject dataObject = data.getJSONObject(i);
            CTopToutiaoAdvertiser toutiaoAdvertiser = new CTopToutiaoAdvertiser(dataObject,accountId);
            //清除清数据，插入新数据
            cTopToutiaoAdvertiserMapper.deleteById(toutiaoAdvertiser.getId());
            cTopToutiaoAdvertiserMapper.insert(toutiaoAdvertiser);
        }
        resultMap.put("code",0);
        resultMap.put("message","获取广告主信息成功");
        return resultMap;
    }

    private void getAdvertiserPlanByPageNumber(String accountId, Integer pageNumber,String ids){
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_ad_get");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        TreeMap<String,Object>params = new TreeMap<>();
        params.put("advertiser_id",cTopOauthToken.getAccountId());
        params.put("page",pageNumber+"");
        JSONObject filtering = new JSONObject();
        if(null!=ids&&!"".equals(ids.trim())){
            String[] idsArray = ids.split(",");
            JSONArray filterIdsArray = new JSONArray();
            for (int i=0;i<idsArray.length;i++){
                Long id = Long.parseLong(idsArray[i]);
                filterIdsArray.add(id);
            }
            filtering.put("ids",filterIdsArray);
        }
        params.put("filtering",filtering.toJSONString());

        String result = HttpUtils.httpGetRequest(url,headers,params);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("获取广告主广告计划信息接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            return ;
        }
        JSONArray data = jsonObject.getJSONObject("data").getJSONArray("list");
        if(null==data||data.size()<=0){
            logger.info("获取广告主广告计划信息不存在==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            return ;
        }
        for (int i=0;i<data.size();i++){
            JSONObject dataObject = data.getJSONObject(i);
            CTopToutiaoAdvertisePlan toutiaoAdvertisePlan = new CTopToutiaoAdvertisePlan(dataObject,accountId);
            //清除清数据，插入新数据
            cTopToutiaoAdvertisePlanMapper.deleteById(toutiaoAdvertisePlan.getId());
            cTopToutiaoAdvertisePlanMapper.insert(toutiaoAdvertisePlan);
        }
        getAdvertiserPlanByPageNumber(accountId,pageNumber+1,ids);
    }
    @Autowired
    private CTopToutiaoAdvertisePlanMapper cTopToutiaoAdvertisePlanMapper;
    @Override
    public Map<String, Object> getAdvertiserPlan(String accountId,String ids) {
        getAdvertiserPlanByPageNumber(accountId,1,ids);
        Map<String,Object>resultMap = new HashMap<>();
        resultMap.put("code",0);
        resultMap.put("message","获取广告计划信息成功");
        return resultMap;
    }

    @Override
    public Map<String, Object> getAdvertiserCampaign(String accountId,String ids) {
        getAdvertiserCampaignByPageNumber(accountId,1,ids);
        Map<String,Object>resultMap = new HashMap<>();
        resultMap.put("code",0);
        resultMap.put("message","获取广告組信息成功");
        return resultMap;
    }

    @Override
    public Map<String, Object> getAdvertiserBudget(String accountId) {
        Map<String,Object>resultMap = new HashMap<>();
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_campaign_get");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        TreeMap<String,Object>params = new TreeMap<>();
        params.put("advertiser_ids","["+cTopOauthToken.getAccountId()+"]");
        String result = HttpUtils.httpGetRequest(url,headers,params);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("获取广告预算信息接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","获取广告预算信息接口异常");
            return resultMap;
        }
        JSONArray data = jsonObject.getJSONArray("data");
        if(null==data||data.size()<=0){
            logger.info("广告主预算信息不存在==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",0);
            resultMap.put("message","获取广告主预算信息完成");
            return resultMap;
        }
        for (int i=0;i<data.size();i++){
            JSONObject dataObject = data.getJSONObject(i);
            CtopToutiaoAdvertiserBudget budget = new CtopToutiaoAdvertiserBudget(dataObject,accountId);
            //清除清数据，插入新数据
            ctopToutiaoAdvertiserBudgetMapper.deleteById(budget.getId());
            ctopToutiaoAdvertiserBudgetMapper.insert(budget);
        }
        resultMap.put("code",0);
        resultMap.put("message","获取广告预算信息完成");
        return resultMap;
    }

    @Override
    public Map<String, Object> getAdvertiserCreative(String accountId,String ids) {
        Map<String,Object>resultMap = new HashMap<>();
        getAdvertiserCreativeByPageNumber(accountId,1,ids);
        resultMap.put("code",0);
        resultMap.put("message","获取广告主广告创意信息完成");
        return resultMap;
    }

    @Override
    public Map<String, Object> getAdvertiserCreativeMaterial(String accountId, String creativeIds) {
        Map<String,Object>resultMap = new HashMap<>();
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_creative_material_get");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        TreeMap<String,Object>params = new TreeMap<>();
        params.put("advertiser_id",cTopOauthToken.getAccountId());
        params.put("creative_ids","["+creativeIds+"]");
        String result = HttpUtils.httpGetRequest(url,headers,params);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("获取广告主创意素材信息接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","获取广告主创意素材信息接口异常");
            return resultMap;
        }
        JSONArray data = jsonObject.getJSONArray("data");
        if(null==data||data.size()<=0){
            logger.info("广告主创意素材信息不存在==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",0);
            resultMap.put("message","获取广告主预算信息完成");
            return resultMap;
        }
        for (int i=0;i<data.size();i++){
            JSONObject dataObject = data.getJSONObject(i);
            ToutiaoCreativeMaterial material = new ToutiaoCreativeMaterial(dataObject,accountId);
            //清除清数据，插入新数据
            toutiaoCreativeMaterialMapper.deleteById(material.getId());
            toutiaoCreativeMaterialMapper.insert(material);
        }
        resultMap.put("code",0);
        resultMap.put("message","获取广告主预算信息完成");
        return resultMap;
    }

    @Override
    public Map<String, Object> advertiserCampaignCreate(String accountId, String campaignName, String budgetMode, Integer budget, String landingType) {
        Map<String,Object>resultMap = new HashMap<>();
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_campaign_create");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        JSONObject params = new JSONObject();
        params.put("advertiser_id",cTopOauthToken.getAccountId());
        params.put("campaign_name",campaignName);
        params.put("budget_mode",budgetMode);
        params.put("budget",budget);
        params.put("landing_type",landingType);
        String result = HttpUtils.httpPostRequest(url,params,headers);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("创建广告组接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","创建广告组接口异常");
            return resultMap;
        }
        JSONObject data = jsonObject.getJSONObject("data");
        if(null==data){
            logger.info("广告组创建异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","广告组创建异常");
            return resultMap;
        }
        Long id =  data.getLong("campaign_id");
        CTopToutiaoCampaign campaign = new CTopToutiaoCampaign(id,cTopOauthToken,campaignName,budgetMode,budget,landingType);
        //清除清数据，插入新数据
        cTopToutiaoCampaignMapper.insert(campaign);
        resultMap.put("code",0);
        resultMap.put("message","广告组创建成功");
        return resultMap;
    }

    @Override
    public Map<String, Object> advertiserCampaignUpdateStatus(String accountId, String campaignIds, String optStatus) {
        Map<String,Object>resultMap = new HashMap<>();
        JSONArray ids = new JSONArray();
        String [] getIds = campaignIds.split(",");
        if(null!=getIds&&getIds.length>0){
            for(int i=0;i<getIds.length;i++){
                ids.add(Long.parseLong(getIds[i]));
            }
        }
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_campaign_update_status");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        JSONObject params = new JSONObject();
        params.put("advertiser_id",cTopOauthToken.getAccountId());
        params.put("campaign_ids",ids);
        params.put("opt_status",optStatus);
        String result = HttpUtils.httpPostRequest(url,params,headers);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("广告组更新状态接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","广告组更新状态接口异常");
            return resultMap;
        }
        JSONObject data = jsonObject.getJSONObject("data");
        if(null==data){
            logger.info("广告组更新状态异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","广告组更新状态异常");
            return resultMap;
        }
        JSONArray getCampaignIds =  data.getJSONArray("campaign_ids");
        if(null!=getCampaignIds&&getCampaignIds.size()>0){
            for(int i=0;i<getCampaignIds.size();i++){
                Long id = getCampaignIds.getLong(i);
                CTopToutiaoCampaign campaign = cTopToutiaoCampaignMapper.selectById(id);
                if(null!=campaign){
                    campaign.setOptStatus(optStatus);
                }
                cTopToutiaoCampaignMapper.updateById(campaign);
            }
        }
        resultMap.put("code",0);
        resultMap.put("message","广告组状态修改成功");
        return resultMap;
    }

    @Override
    public Map<String, Object> advertiserCampaignUpdate(String accountId, Long campaignId, String budgetMode, Integer budget,String campaignName) {
        Map<String,Object>resultMap = new HashMap<>();
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        CTopToutiaoCampaign campaign = cTopToutiaoCampaignMapper.selectById(campaignId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_campaign_update");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        JSONObject params = new JSONObject();
        params.put("advertiser_id",cTopOauthToken.getAccountId());
        params.put("campaign_id",campaignId);
        params.put("modify_time",campaign.getModifyTime());
        params.put("campaign_id",campaignId);
        if(null!=campaignName&&!"".equals(campaignName.trim())){
            params.put("campaign_name",campaignName);
        }
        if(null!=budgetMode&&!"".equals(budgetMode.trim())){
            params.put("budget_mode",budgetMode);
        }
        if(null!=budget){
            params.put("budget",budget);
        }
        String result = HttpUtils.httpPostRequest(url,params,headers);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("广告组更新接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","广告组更新接口异常");
            return resultMap;
        }
        JSONObject data = jsonObject.getJSONObject("data");
        if(null==data){
            logger.info("广告组更新异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","广告组更新异常");
            return resultMap;
        }
        if(null!=campaignName&&!"".equals(campaignName.trim())){
            campaign.setName(campaignName);
        }
        if(null!=budgetMode&&!"".equals(budgetMode.trim())){
            params.put("budget_mode",budgetMode);
            campaign.setBudgetMode(budgetMode);
        }
        if(null!=budget){
            campaign.setBudget(new BigDecimal(budget));
        }
        cTopToutiaoCampaignMapper.updateById(campaign);

        resultMap.put("code",0);
        resultMap.put("message","广告组信息修改成功");
        return resultMap;
    }

    @Override
    public Map<String, Object> advertiserPlanUpdateStatus(String accountId, String adIds, String optStatus) {
        Map<String,Object>resultMap = new HashMap<>();
        JSONArray ids = new JSONArray();
        String [] getIds = adIds.split(",");
        if(null!=getIds&&getIds.length>0){
            for(int i=0;i<getIds.length;i++){
                ids.add(Long.parseLong(getIds[i]));
            }
        }
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_ad_update_status");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        JSONObject params = new JSONObject();
        params.put("advertiser_id",cTopOauthToken.getAccountId());
        params.put("ad_ids",ids.toJSONString());
        params.put("opt_status",optStatus);
        String result = HttpUtils.httpPostRequest(url,params,headers);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("广告计划更新状态接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","广告计划更新状态接口异常");
            return resultMap;
        }
        JSONObject data = jsonObject.getJSONObject("data");
        if(null==data){
            logger.info("广告计划更新状态异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","广告计划更新状态异常");
            return resultMap;
        }
        JSONArray getAdIds =  data.getJSONArray("ad_ids");
        if(null!=getAdIds&&getAdIds.size()>0){
            //获取广告计划信息
            getAdvertiserPlan(accountId,adIds);
        }
        resultMap.put("code",0);
        resultMap.put("message","广告组状态修改成功");
        return resultMap;
    }

    @Override
    public Map<String, Object> advertiserPlanUpdateBid(String accountId, String adIds, String bids) {
        //TODO 校验数据是否完整
        Map<String,Object>resultMap = new HashMap<>();
        JSONArray data = new JSONArray();
        String [] getadIds = adIds.split(",");
        String [] getBids = bids.split(",");
        if(null!=getadIds&&getadIds.length>0){
            for(int i=0;i<getadIds.length;i++){
                JSONObject object = new JSONObject();
                Long ad_id = Long.parseLong(getadIds[i]);
                Long bid = Long.parseLong(getBids[i]);
                object.put("ad_id",ad_id);
                object.put("bid",bid);
                data.add(object);
            }
        }
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_ad_update_bid");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        JSONObject params = new JSONObject();
        params.put("advertiser_id",cTopOauthToken.getAccountId());
        params.put("data",data.toJSONString());
        String result = HttpUtils.httpPostRequest(url,params,headers);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("修改计划出价接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","修改计划出价接口异常");
            return resultMap;
        }
        JSONObject getData = jsonObject.getJSONObject("data");
        if(null==getData){
            logger.info("修改计划出价异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","修改计划出价异常");
            return resultMap;
        }
        JSONArray getAdIds = getData.getJSONArray("ad_ids");
        if(null!=getAdIds&&getAdIds.size()>0){
            //获取广告计划信息
            getAdvertiserPlan(accountId,adIds);
        }
        resultMap.put("code",0);
        resultMap.put("message","修改计划出价成功");
        return resultMap;
    }

    @Override
    public Map<String, Object> advertiserPlanUpdateBudget(String accountId, String adIds, String budgets) {
        //TODO 校验数据是否完整
        Map<String,Object>resultMap = new HashMap<>();
        JSONArray data = new JSONArray();
        String [] getadIds = adIds.split(",");
        String [] getBudgets = budgets.split(",");
        if(null!=getadIds&&getadIds.length>0){
            for(int i=0;i<getadIds.length;i++){
                JSONObject object = new JSONObject();
                Long ad_id = Long.parseLong(getadIds[i]);
                Long budget = Long.parseLong(getBudgets[i]);
                object.put("ad_id",ad_id);
                object.put("budget",budget);
                data.add(object);
            }
        }
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_ad_update_budget");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        JSONObject params = new JSONObject();
        params.put("advertiser_id",cTopOauthToken.getAccountId());
        params.put("data",data.toJSONString());
        String result = HttpUtils.httpPostRequest(url,params,headers);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");
        if(null==code||!code.equals(0)){
            logger.info("修改计划预算接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","修改计划预算接口异常");
            return resultMap;
        }
        JSONObject getData = jsonObject.getJSONObject("data");
        if(null==getData){
            logger.info("修改计划预算异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","修改计划预算异常");
            return resultMap;
        }
        JSONArray getAdIds = getData.getJSONArray("ad_ids");
        if(null!=getAdIds&&getAdIds.size()>0){
            //获取广告计划信息
            getAdvertiserPlan(accountId,adIds);
        }
        resultMap.put("code",0);
        resultMap.put("message","修改计划预算成功");
        return resultMap;
    }

    @Override
    public Map<String, Object> advertiserCreativeUpdateStatus(String accountId, String creativeIds, String optStatus) {
        Map<String,Object>resultMap = new HashMap<>();
        JSONArray ids = new JSONArray();
        String [] getCreativeIds = creativeIds.split(",");
        if(null!=getCreativeIds&&getCreativeIds.length>0){
            for(int i=0;i<getCreativeIds.length;i++){
                ids.add(Long.parseLong(getCreativeIds[i]));
            }
        }
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_creative_update_status");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        JSONObject params = new JSONObject();
        params.put("advertiser_id",cTopOauthToken.getAccountId());
        params.put("creative_ids",ids.toJSONString());
        params.put("opt_status",optStatus);
        String result = HttpUtils.httpPostRequest(url,params,headers);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("修改创意状态接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","修改创意状态接口异常");
            return resultMap;
        }
        JSONObject data = jsonObject.getJSONObject("data");
        if(null==data){
            logger.info("修改创意状态异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            resultMap.put("code",-1);
            resultMap.put("message","修改创意状态异常");
            return resultMap;
        }
        JSONArray returnCreativeIds =  data.getJSONArray("creative_ids");
        if(null!=returnCreativeIds&&returnCreativeIds.size()>0){
            //TODO 获取广告计划信息 需要注意这里的逻辑 有漏洞，后期修改
            getAdvertiserCreative(accountId,creativeIds);
        }
        resultMap.put("code",0);
        resultMap.put("message","广告创意状态修改成功");
        return resultMap;
    }

    @Autowired
    private ToutiaoCreativeMaterialMapper toutiaoCreativeMaterialMapper;

    private void getAdvertiserCreativeByPageNumber(String accountId, Integer pageNumber,String ids){
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_creative_get");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        TreeMap<String,Object>params = new TreeMap<>();
        JSONObject filtering = new JSONObject();
        if(null!=ids&&!"".equals(ids.trim())){
            String[] idsArray = ids.split(",");
            JSONArray filterIdsArray = new JSONArray();
            for (int i=0;i<idsArray.length;i++){
                Long id = Long.parseLong(idsArray[i]);
                filterIdsArray.add(id);
            }
            filtering.put("ids",filterIdsArray);
        }
        params.put("filtering",filtering.toJSONString());
        params.put("advertiser_id",cTopOauthToken.getAccountId());
        params.put("page",pageNumber+"");
        String result = HttpUtils.httpGetRequest(url,headers,params);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("获取广告主广告创意信息接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            return ;
        }
        JSONArray data = jsonObject.getJSONObject("data").getJSONArray("list");
        if(null==data||data.size()<=0){
            logger.info("广告主广告创意信息不存在==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            return ;
        }
        for (int i=0;i<data.size();i++){
            JSONObject dataObject = data.getJSONObject(i);
            ToutiaoCreative creative = new ToutiaoCreative(dataObject,accountId);
            //清除清数据，插入新数据
            toutiaoCreativeMapper.deleteById(creative.getId());
            toutiaoCreativeMapper.insert(creative);
        }
        getAdvertiserCreativeByPageNumber(accountId,pageNumber+1,ids);
    }

    @Autowired
    private ToutiaoCreativeMapper toutiaoCreativeMapper;
    @Autowired
    private CtopToutiaoAdvertiserBudgetMapper ctopToutiaoAdvertiserBudgetMapper;

    private void getAdvertiserCampaignByPageNumber(String accountId, Integer pageNumber,String ids){
        CTopOauthToken cTopOauthToken = getOAuthTokenByAccountId(accountId);
        //2: 根据token以及用户id获取用户信息数据
        String url = PropertiesUtils.getValue("bytedance_config","bytedance_api_url")+PropertiesUtils.getValue("bytedance_config","bytedance_v2_campaign_get");
        Map<String,String> headers = new HashMap<>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",cTopOauthToken.getAccessToken());

        TreeMap<String,Object> params = new TreeMap<>();
        JSONObject filtering = new JSONObject();
        if(null!=ids&&!"".equals(ids.trim())){
            String[] idsArray = ids.split(",");
            JSONArray filterIdsArray = new JSONArray();
            for (int i=0;i<idsArray.length;i++){
                Long id = Long.parseLong(idsArray[i]);
                filterIdsArray.add(id);
            }
            filtering.put("ids",filterIdsArray);
        }
        params.put("filtering",filtering.toJSONString());
        params.put("advertiser_id",cTopOauthToken.getAccountId());
        params.put("page",pageNumber+"");
        String result = HttpUtils.httpGetRequest(url,headers,params);
        JSONObject jsonObject = JSONObject.parseObject(result);
        Integer code = jsonObject.getInteger("code");

        if(null==code||!code.equals(0)){
            logger.info("获取广告主广告组信息接口异常==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            return ;
        }
        JSONArray data = jsonObject.getJSONObject("data").getJSONArray("list");
        if(null==data||data.size()<=0){
            logger.info("获取广告主广告组信息不存在==》accountId:{},message:{}",accountId,jsonObject.getString("message"));
            return ;
        }
        for (int i=0;i<data.size();i++){
            JSONObject dataObject = data.getJSONObject(i);
            CTopToutiaoCampaign toutiaoCampaign = new CTopToutiaoCampaign(dataObject,accountId);
            //清除清数据，插入新数据
            cTopToutiaoCampaignMapper.deleteById(toutiaoCampaign.getId());
            cTopToutiaoCampaignMapper.insert(toutiaoCampaign);
        }
        getAdvertiserCampaignByPageNumber(accountId,pageNumber+1,ids);
    }
    @Autowired
    private CTopToutiaoCampaignMapper cTopToutiaoCampaignMapper;

    @Autowired
    private CTopToutiaoAdvertiserMapper cTopToutiaoAdvertiserMapper;
}
