package cn.com.ctop.kuaishou.modules.material.service.impl;

import cn.com.ctop.common.utils.HttpUtils;
import cn.com.ctop.common.utils.PropertiesUtils;
import cn.com.ctop.kuaishou.modules.material.entity.*;
import cn.com.ctop.kuaishou.modules.material.service.IKuaishouInterfaceService;
import cn.com.ctop.kuaishou.modules.report.entity.*;
import com.fasterxml.jackson.core.JsonParseException;

import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;

import com.fasterxml.jackson.databind.type.TypeFactory;
import constant.KuaishouInterfaceConstant;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.HashMap;
import java.util.Map;

@Service
public class KuaishouInterfaceServiceImpl implements IKuaishouInterfaceService {


    public KuaishouResult<KuaishouReportHourlyAccount> getAccountHourlyReport(String accessToken, Long advertiserId, String startDate, String endDate, int pageSize, int pageNum){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+ KuaishouInterfaceConstant.ACCOUNT_REPORT;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",accessToken);
        Map<String,Object> param = new HashMap<String,Object>();
        param.put("start_date",startDate);
        param.put("end_date",endDate);
        param.put("advertiser_id",advertiserId);
        param.put("temporal_granularity","HOURLY");
        param.put("page_size",pageSize);
        param.put("page",pageNum);
        KuaishouResult<KuaishouReportHourlyAccount> kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResult<KuaishouReportHourlyAccount>>(){});
//            kuaishouResult = (KuaishouResult<KuaishouReportHourlyAccount>)jsonToObj(KuaishouResult.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResult<KuaishouReportDailyAccount> getAccountDailyReport(String accessToken, Long advertiserId, String startDate, String endDate, int pageSize, int pageNum){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+ KuaishouInterfaceConstant.ACCOUNT_REPORT;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",accessToken);
        Map<String,Object> param = new HashMap<String,Object>();
        param.put("start_date",startDate);
        param.put("end_date",endDate);
        param.put("advertiser_id",advertiserId);
        param.put("temporal_granularity","DAILY");
        param.put("page_size",pageSize);
        param.put("page",pageNum);
        KuaishouResult<KuaishouReportDailyAccount> kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResult<KuaishouReportDailyAccount>>(){});
//            kuaishouResult = (KuaishouResult<KuaishouReportDailyAccount>)jsonToObj(KuaishouResult.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResult<KuaishouReportDailyCampaign> getCampaignDailyReport(String accessToken, Long advertiserId, String startDate, String endDate, int pageSize, int pageNum){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+ KuaishouInterfaceConstant.CAMPAIGN_REPORT;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",accessToken);
        Map<String,Object> param = new HashMap<String,Object>();
        param.put("start_date",startDate);
        param.put("end_date",endDate);
        param.put("advertiser_id",advertiserId);
        param.put("temporal_granularity","DAILY");
        param.put("page_size",pageSize);
        param.put("page",pageNum);
        KuaishouResult<KuaishouReportDailyCampaign> kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResult<KuaishouReportDailyCampaign>>(){});
//            kuaishouResult = (KuaishouResult<KuaishouReportDailyCampaign>)jsonToObj(KuaishouResult.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResult<KuaishouReportHourlyCampaign> getCampaignHourlyReport(String accessToken, Long advertiserId, String startDate, String endDate, int pageSize, int pageNum){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+ KuaishouInterfaceConstant.CAMPAIGN_REPORT;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",accessToken);
        Map<String,Object> param = new HashMap<String,Object>();
        param.put("start_date",startDate);
        param.put("end_date",endDate);
        param.put("advertiser_id",advertiserId);
        param.put("temporal_granularity","HOURLY");
        param.put("page_size",pageSize);
        param.put("page",pageNum);
        KuaishouResult<KuaishouReportHourlyCampaign> kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResult<KuaishouReportHourlyCampaign>>(){});
//            kuaishouResult = (KuaishouResult<KuaishouReportDailyCampaign>)jsonToObj(KuaishouResult.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResult<KuaishouReportDailyGroup> getGroupDailyReport(String accessToken, Long advertiserId, String startDate, String endDate, int pageSize, int pageNum){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+ KuaishouInterfaceConstant.GTOUP_REPORT;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",accessToken);
        Map<String,Object> param = new HashMap<String,Object>();
        param.put("start_date",startDate);
        param.put("end_date",endDate);
        param.put("advertiser_id",advertiserId);
        param.put("temporal_granularity","DAILY");
        param.put("page_size",pageSize);
        param.put("page",pageNum);
        KuaishouResult<KuaishouReportDailyGroup> kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResult<KuaishouReportDailyGroup>>(){});
//            kuaishouResult = (KuaishouResult<KuaishouReportDailyGroup>)jsonToObj(KuaishouResult.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResult<KuaishouReportHourlyGroup> getGroupHourlyReport(String accessToken, Long advertiserId, String startDate, String endDate, int pageSize, int pageNum){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+ KuaishouInterfaceConstant.GTOUP_REPORT;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",accessToken);
        Map<String,Object> param = new HashMap<String,Object>();
        param.put("start_date",startDate);
        param.put("end_date",endDate);
        param.put("advertiser_id",advertiserId);
        param.put("temporal_granularity","HOURLY");
        param.put("page_size",pageSize);
        param.put("page",pageNum);
        KuaishouResult<KuaishouReportHourlyGroup> kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResult<KuaishouReportHourlyGroup>>(){});
//            kuaishouResult = (KuaishouResult<KuaishouReportDailyGroup>)jsonToObj(KuaishouResult.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResult<KuaishouReportDailyCreative> getCreativeDailyReport(String accessToken, Long advertiserId, String startDate, String endDate, int pageSize, int pageNum){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+ KuaishouInterfaceConstant.CREATIVE_REPORT;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",accessToken);
        Map<String,Object> param = new HashMap<String,Object>();
        param.put("start_date",startDate);
        param.put("end_date",endDate);
        param.put("advertiser_id",advertiserId);
        param.put("temporal_granularity","DAILY");
        param.put("page_size",pageSize);
        param.put("page",pageNum);
        KuaishouResult<KuaishouReportDailyCreative> kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResult<KuaishouReportDailyCreative>>(){});
//            kuaishouResult = (KuaishouResult<KuaishouReportDailyCreative>)jsonToObj(KuaishouResult.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResult<KuaishouReportHourlyCreative> getCreativeHourlyReport(String accessToken, Long advertiserId, String startDate, String endDate, int pageSize, int pageNum){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+ KuaishouInterfaceConstant.CREATIVE_REPORT;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",accessToken);
        Map<String,Object> param = new HashMap<String,Object>();
        param.put("start_date",startDate);
        param.put("end_date",endDate);
        param.put("advertiser_id",advertiserId);
        param.put("temporal_granularity","HOURLY");
        param.put("page_size",pageSize);
        param.put("page",pageNum);
        KuaishouResult<KuaishouReportHourlyCreative> kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResult<KuaishouReportHourlyCreative>>(){});
//            kuaishouResult = (KuaishouResult<KuaishouReportDailyCreative>)jsonToObj(KuaishouResult.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResult<KuaishouCampaign> getCampaignList(String accessToken, Long advertiserId){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+ KuaishouInterfaceConstant.CAMPAIGN_LIST;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",accessToken);
        Map<String,Object> param = new HashMap<String,Object>();
        param.put("advertiser_id",advertiserId);
        KuaishouResult<KuaishouCampaign> kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResult<KuaishouCampaign>>(){});
//            kuaishouResult = (KuaishouResult<KuaishouCampaign>)jsonToObj(KuaishouResult.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResult<KuaishouGroup> getGroupList(String accessToken, Long advertiserId){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+ KuaishouInterfaceConstant.GROUP_LIST;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",accessToken);
        Map<String,Object> param = new HashMap<String,Object>();
        param.put("advertiser_id",advertiserId);
        KuaishouResult<KuaishouGroup> kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResult<KuaishouGroup>>(){});
//            kuaishouResult = (KuaishouResult<KuaishouGroup>)jsonToObj(KuaishouResult.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResult<KuaishouCreative> getCreativeList(String accessToken, Long advertiserId){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+ KuaishouInterfaceConstant.CREATIVE_LIST;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        headers.put("Access-Token",accessToken);
        Map<String,Object> param = new HashMap<String,Object>();
        param.put("advertiser_id",advertiserId);
        KuaishouResult<KuaishouCreative> kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResult<KuaishouCreative>>(){});
//            kuaishouResult = (KuaishouResult<KuaishouCreative>)jsonToObj(KuaishouResult.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResultToken getAccessToken(String authCode){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+KuaishouInterfaceConstant.AUTH_TOKEN;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("app_id",PropertiesUtils.getConfig("kuaishou_appid"));
        param.put("secret",PropertiesUtils.getConfig("kuaishou_secret"));
        param.put("auth_code",authCode);

        KuaishouResultToken kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResultToken>(){});
//            kuaishouResult = (KuaishouResultToken)jsonToObj(KuaishouResultToken.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public KuaishouResultToken getRefreshToken(String refreshToken){
        String url = PropertiesUtils.getConfig("kuaishou_api_url")+KuaishouInterfaceConstant.REFRESH_TOKEN;
        Map<String,String> headers = new HashMap<String,String>();
        headers.put("Content-Type","application/json");
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("app_id",PropertiesUtils.getConfig("kuaishou_appid"));
        param.put("secret",PropertiesUtils.getConfig("kuaishou_secret"));
        param.put("refresh_token",refreshToken);

        KuaishouResultToken kuaishouResult = null;
        try{
            String result = HttpUtils.httpPostRequest(url,param,headers);
            System.out.println(result);
            ObjectMapper mapper = new ObjectMapper();
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            kuaishouResult = mapper.readValue(result,new TypeReference<KuaishouResultToken>(){});
//            kuaishouResult = (KuaishouResultToken)jsonToObj(KuaishouResultToken.class,result);
        }catch (Exception e){
            e.printStackTrace();
        }
        return kuaishouResult;
    }

    public Object jsonToObj(Object t,String jsonStr) throws JsonParseException, JsonMappingException, IOException {
        ObjectMapper mapper = new ObjectMapper();

        mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
        return mapper.readValue(jsonStr, new TypeReference<Object>(){});
    }

    public JavaType getJavaType(Type type) {
        //判断是否带有泛型
        if (type instanceof ParameterizedType)
        {
            Type[] actualTypeArguments = ((ParameterizedType) type).getActualTypeArguments();
            //获取泛型类型
            Class rowClass = (Class) ((ParameterizedType) type).getRawType();
            JavaType[] javaTypes = new JavaType[actualTypeArguments.length];
            for (int i = 0; i < actualTypeArguments.length; i++)
            {
                //泛型也可能带有泛型，递归获取
                javaTypes[i] = getJavaType(actualTypeArguments[i]);
            }
            return TypeFactory.defaultInstance().constructParametricType(rowClass, javaTypes);
        } else {
            //简单类型直接用该类构建
            Class cla = (Class) type;
            return TypeFactory.defaultInstance().constructParametricType(cla, new JavaType[0]);
        }
    }
}
